Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(759)

Unified Diff: src/mark-compact.h

Issue 10386046: Implement map collection for incremental marking. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/mark-compact.h
diff --git a/src/mark-compact.h b/src/mark-compact.h
index 6420a21fe3b0ac746706bf13605188c80e1bf83e..8bee6ab9dcab0e546d4e84f8ca75e7b1bdfeaf71 100644
--- a/src/mark-compact.h
+++ b/src/mark-compact.h
@@ -584,7 +584,7 @@ class MarkCompactCollector {
bool was_marked_incrementally_;
- bool collect_maps_;
+ bool clear_map_transitions_;
bool flush_monomorphic_ics_;
@@ -608,12 +608,12 @@ class MarkCompactCollector {
//
// After: Live objects are marked and non-live objects are unmarked.
-
friend class RootMarkingVisitor;
friend class MarkingVisitor;
friend class StaticMarkingVisitor;
friend class CodeMarkingVisitor;
friend class SharedFunctionInfoMarkingVisitor;
+ friend class IncrementalMarking;
// Mark non-optimize code for functions inlined into the given optimized
// code. This will prevent it from being flushed.
@@ -642,8 +642,9 @@ class MarkCompactCollector {
void ProcessNewlyMarkedObject(HeapObject* obj);
- // Mark a Map and its DescriptorArray together, skipping transitions.
- void MarkMapContents(Map* map);
+ // Mark weak pointers in a Map and its DescriptorArray together, possibly
+ // skipping transitions or back pointers.
+ void MarkWeakMapContents(Map* map);
void MarkAccessorPairSlot(HeapObject* accessors, int offset);
void MarkDescriptorArray(DescriptorArray* descriptors);

Powered by Google App Engine
This is Rietveld 408576698